@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -38,7 +38,7 @@ from yapf.yapflib import py3compat
 from yapf.yapflib import style
 from yapf.yapflib import yapf_api
 
-__version__ = '0.8.0'
+__version__ = '0.10.0'
 
 
 def main(argv):
@@ -103,9 +103,7 @@ def main(argv):
   parser.add_argument('--no-local-style',
                       action='store_true',
                       help="don't search for local style definition")
-  parser.add_argument('--verify',
-                      action='store_true',
-                      help='try to verify reformatted code for syntax errors')
+  parser.add_argument('--verify', action='store_true', help=argparse.SUPPRESS)
 
   parser.add_argument('files', nargs='*')
   args = parser.parse_args(argv[1:])
