@@ -1,4 +1,4 @@
-# Copyright 2015 Google Inc. All Rights Reserved.
+# Copyright 2015-2016 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -100,10 +100,10 @@ def _FindPythonFiles(filenames, recursive, exclude):
     if os.path.isdir(filename):
       if recursive:
         # TODO(morbo): Look into a version of os.walk that can handle recursion.
-        python_files.extend(
-            os.path.join(dirpath, f)
-            for dirpath, _, filelist in os.walk(filename) for f in filelist
-            if IsPythonFile(os.path.join(dirpath, f)))
+        python_files.extend(os.path.join(dirpath, f)
+                            for dirpath, _, filelist in os.walk(filename)
+                            for f in filelist
+                            if IsPythonFile(os.path.join(dirpath, f)))
       else:
         raise errors.YapfError(
             "directory specified without '--recursive' flag: %s" % filename)
@@ -111,8 +111,7 @@ def _FindPythonFiles(filenames, recursive, exclude):
       python_files.append(filename)
 
   if exclude:
-    return [f
-            for f in python_files
+    return [f for f in python_files
             if not any(fnmatch.fnmatch(f, p) for p in exclude)]
 
   return python_files
